<?php
namespace Pinpoint\Feed\Helper;

use Magento\Store\Model\ScopeInterface;

/**
 * Class Data
 * @package Pinpoint\Feed\Helper
 */
class Data extends \Magento\Framework\App\Helper\AbstractHelper
{
    /**
     * @var string
     */
    const XML_PATH_PRODUCT_FILENAME = 'feeds/product_feed/filename';

    /**
     * @var string
     */
    const XML_PATH_PRODUCT_FILEPATH = 'feeds/product_feed/filepath';

    /**
     * @var string
     */
    const XML_PATH_PRODUCT_ENABLED = 'feeds/product_feed/enabled';

    /**
     * @var string
     */
    const XML_PATH_PRODUCT_FEED_FIELD = 'feeds/product_feed/';

    /**
     * @var string
     */
    const XML_PATH_PAGE_FILENAME = 'feeds/page_feed/filename';

    /**
     * @var string
     */
    const XML_PATH_PAGE_FILEPATH = 'feeds/page_feed/filepath';

    /**
     * @var string
     */
    const XML_PATH_PAGE_ENABLED = 'feeds/page_feed/enabled';

    /**
     * @var string
     */
    const XML_PATH_BLOG_FILENAME = 'feeds/blog_feed/filename';

    /**
     * @var string
     */
    const XML_PATH_BLOG_FILEPATH = 'feeds/blog_feed/filepath';

    /**
     * @var string
     */
    const XML_PATH_BLOG_ENABLED = 'feeds/blog_feed/enabled';

    /**
     * @param $storeId
     * @return bool
     */
    public function isProductFeedEnabled($storeId)
    {
        return $this->scopeConfig->getValue(
            self::XML_PATH_PRODUCT_ENABLED,
            ScopeInterface::SCOPE_STORE,
            $storeId
        ) == '1';
    }

    /**
     * @param $storeId
     * @return mixed
     */
    public function getProductFeedFilename($storeId)
    {
        return $this->scopeConfig->getValue(
            self::XML_PATH_PRODUCT_FILENAME,
            ScopeInterface::SCOPE_STORE,
            $storeId
        );
    }

    /**
     * @param $storeId
     * @return mixed
     */
    public function getProductFeedFilepath($storeId)
    {
        return $this->scopeConfig->getValue(
            self::XML_PATH_PRODUCT_FILEPATH,
            ScopeInterface::SCOPE_STORE,
            $storeId
        );
    }

    /**
     * @param $storeId
     * @return bool
     */
    public function isPageFeedEnabled($storeId)
    {
        return $this->scopeConfig->getValue(
            self::XML_PATH_PAGE_ENABLED,
            ScopeInterface::SCOPE_STORE,
            $storeId
        ) == '1';
    }

    /**
     * @param $storeId
     * @return mixed
     */
    public function getPageFeedFilename($storeId)
    {
        return $this->scopeConfig->getValue(
            self::XML_PATH_PAGE_FILENAME,
            ScopeInterface::SCOPE_STORE,
            $storeId
        );
    }

    /**
     * @param $storeId
     * @return mixed
     */
    public function getPageFeedFilepath($storeId)
    {
        return $this->scopeConfig->getValue(
            self::XML_PATH_PAGE_FILEPATH,
            ScopeInterface::SCOPE_STORE,
            $storeId
        );
    }

    /**
     * @param $fieldName
     * @param $storeId
     * @return mixed
     */
    public function getProductFeedField($fieldName, $storeId)
    {
        $alias =  $this->scopeConfig->getValue(
            self::XML_PATH_PRODUCT_FEED_FIELD .  $fieldName,
            ScopeInterface::SCOPE_STORE,
            $storeId
        );

        if (trim($alias)) {
            return $alias;
        } else {
            return $fieldName;
        }
    }

    /**
     * @param $storeId
     * @return bool
     */
    public function isBlogFeedEnabled($storeId)
    {
        return $this->scopeConfig->getValue(
                self::XML_PATH_BLOG_ENABLED,
                ScopeInterface::SCOPE_STORE,
                $storeId
            ) == '1';
    }

    /**
     * @param $storeId
     * @return mixed
     */
    public function getBlogFeedFilename($storeId)
    {
        return $this->scopeConfig->getValue(
            self::XML_PATH_BLOG_FILENAME,
            ScopeInterface::SCOPE_STORE,
            $storeId
        );
    }

    /**
     * @param $storeId
     * @return mixed
     */
    public function getBlogFeedFilepath($storeId)
    {
        return $this->scopeConfig->getValue(
            self::XML_PATH_BLOG_FILEPATH,
            ScopeInterface::SCOPE_STORE,
            $storeId
        );
    }
}