<?php
namespace Pinpoint\Feed\Model;

use Pinpoint\Feed\Helper\Data;

/**
 * Class BlogFeed
 * @package Pinpoint\Feed\Model
 */
class BlogFeed extends AbstractFeed
{

    /**
     * @var \Magefan\Blog\Model\ResourceModel\Post\Collection
     */
    protected $blogCollection;

    /**
     * @var \Magefan\Blog\Model\Url
     */
    protected $blogUrl;

    /**
     * @var int
     */
    protected $_lineCount;

    /**
     * BlogFeed constructor.
     * @param \Magento\Framework\Escaper $escaper
     * @param \Magento\Framework\Filesystem $filesystem
     * @param Data $helper
     * @param \Magefan\Blog\Model\ResourceModel\Post\Collection $blogCollection
     * @param \Magefan\Blog\Model\Url $blogUrl
     * @param \Magento\Framework\Stdlib\DateTime\DateTime $modelDate
     * @param \Magento\Framework\App\RequestInterface $request
     * @param \Magento\Framework\Stdlib\DateTime $dateTime
     * @param \Magento\Framework\Filesystem\Io\File $io
     * @param \Magento\Store\Model\StoreManagerInterface $storeManager
     * @param \Magento\Config\Model\Config\Reader\Source\Deployed\DocumentRoot|null $documentRoot
     * @throws \Magento\Framework\Exception\FileSystemException
     */
    public function __construct(
        \Magento\Framework\Escaper $escaper,
        \Magento\Framework\Filesystem $filesystem,
        Data $helper,
        \Magefan\Blog\Model\ResourceModel\Post\Collection $blogCollection,
        \Magefan\Blog\Model\Url $blogUrl,
        \Magento\Framework\Stdlib\DateTime\DateTime $modelDate,
        \Magento\Framework\App\RequestInterface $request,
        \Magento\Framework\Stdlib\DateTime $dateTime,
        \Magento\Framework\Filesystem\Io\File $io,
        \Magento\Store\Model\StoreManagerInterface $storeManager,
        \Magento\Config\Model\Config\Reader\Source\Deployed\DocumentRoot $documentRoot = null
    ) {
        $this->blogCollection = $blogCollection;
        $this->blogUrl = $blogUrl;

        parent::__construct($escaper, $filesystem, $helper, $modelDate, $request, $dateTime, $io, $storeManager, $documentRoot);
    }

    /**
     * @return $this
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function generateXml()
    {
        if (!$this->helper->isBlogFeedEnabled($this->getStoreId())) {
            return $this;
        }

        $this->prepareFile();
        $this->_lineCount = 0;

        $this->_initSitemapItems();

        $collection = $this->blogCollection->getItems();

        foreach ($collection as $item) {
            $xml = $this->_getRow(
                $item
            );

            if (!$this->_fileSize) {
                $this->_createFeed(null, 'pages');
            }

            $this->_writeRow($xml);
            // Increase counters
            $this->_lineCount++;
            $this->_fileSize += strlen($xml);
        }

        $this->_finalizeFile('pages');

        return $this;
    }

    /**
     * @return mixed
     */
    public function getFilename()
    {
        return $this->helper->getBlogFeedFilename($this->getStoreId());
    }

    /**
     * @return mixed
     */
    public function getFilePath()
    {
        return $this->helper->getBlogFeedFilepath($this->getStoreId());
    }

    /**
     * @param $item
     * @return mixed|string
     */
    protected function _getRow($item)
    {
        $content = str_replace(['<![CDATA[', ']]>'], '', $item->getContent()); //remove cdata from content or it breaks the XML
        $row = '<id>' . $item->getId() . '</id>';
        $row .= '<name><![CDATA[' . $item->getTitle() . ']]></name>';
        $row .= '<desc><![CDATA[' . $content . ']]></desc>';
        $row .= '<metaDesc><![CDATA[' . $item->getMetaDescription() . ']]></metaDesc>';
        $row .= '<metaKeywords><![CDATA[' . $item->getMetaKeywords() . ']]></metaKeywords>';
        $row .= '<category>blog</category>';
        $row .= '<url>' . htmlspecialchars($this->blogUrl->getUrl($item->getIdentifier(), 'post')) . '</url>';

        return '<record>' . $row . '</record>';
    }
}