<?php
namespace Pinpoint\Feed\Model;

use Pinpoint\Feed\Helper\Data;

/**
 * Class PageCmsFeed
 * @package Pinpoint\Feed\Model
 */
class PageCmsFeed extends AbstractFeed
{
    /**
     * @var \Magento\Cms\Model\ResourceModel\Page\CollectionFactory
     */
    protected $pageFactory;

    /**
     * @var \Magento\Cms\Helper\Page
     */
    protected $pageHelper;


    /**
     * PageCmsFeed constructor.
     * @param \Magento\Framework\Escaper $escaper
     * @param \Magento\Framework\Filesystem $filesystem
     * @param Data $helper
     * @param \Magento\Cms\Model\ResourceModel\Page\CollectionFactory $pageFactory
     * @param \Magento\Framework\Stdlib\DateTime\DateTime $modelDate
     * @param \Magento\Framework\App\RequestInterface $request
     * @param \Magento\Framework\Stdlib\DateTime $dateTime
     * @param \Magento\Framework\Filesystem\Io\File $io
     * @param \Magento\Store\Model\StoreManagerInterface $storeManager
     * @param \Magento\Cms\Helper\Page $pageHelper
     * @param \Magento\Config\Model\Config\Reader\Source\Deployed\DocumentRoot|null $documentRoot
     * @throws \Magento\Framework\Exception\FileSystemException
     */
    public function __construct(
        \Magento\Framework\Escaper $escaper,
        \Magento\Framework\Filesystem $filesystem,
        Data $helper,
        \Magento\Cms\Model\ResourceModel\Page\CollectionFactory $pageFactory,
        \Magento\Framework\Stdlib\DateTime\DateTime $modelDate,
        \Magento\Framework\App\RequestInterface $request,
        \Magento\Framework\Stdlib\DateTime $dateTime,
        \Magento\Framework\Filesystem\Io\File $io,
        \Magento\Store\Model\StoreManagerInterface $storeManager,
        \Magento\Cms\Helper\Page $pageHelper,
        \Magento\Config\Model\Config\Reader\Source\Deployed\DocumentRoot $documentRoot = null
    ) {
        $this->pageFactory = $pageFactory;
        $this->pageHelper = $pageHelper;
        parent::__construct($escaper, $filesystem, $helper, $modelDate, $request, $dateTime, $io, $storeManager, $documentRoot);
    }

    /**
     * @return $this|mixed
     * @throws \Magento\Framework\Exception\FileSystemException
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function generateXml()
    {
        if (!$this->helper->isPageFeedEnabled($this->getStoreId())) {
            return $this;
        }

        $this->prepareFile();
        $this->_lineCount = 0;

        $this->_initSitemapItems();

        $collection = $this->pageFactory->create()->addStoreFilter($this->getStoreId());

        foreach ($collection as $item) {
            $xml = $this->_getRow(
                $item
            );

            if (!$this->_fileSize) {
                $this->_createFeed(null, 'pages');
            }

            $this->_writeRow($xml);
            $this->_lineCount++;
            $this->_fileSize += strlen($xml);
        }

        $this->_finalizeFile('pages');

        return $this;
    }

    /**
     * @return mixed
     */
    public function getFilename()
    {
        return $this->helper->getPageFeedFilename($this->getStoreId());
    }

    /**
     * @return mixed
     */
    public function getFilePath()
    {
        return $this->helper->getPageFeedFilepath($this->getStoreId());
    }

    /**
     * @param  \Magento\Cms\Model\Page $item
     * @return string
     */
    protected function _getRow($item)
    {
        $row = '<id>' . $item->getId() . '</id>';
        $row .= '<name><![CDATA[' . $item->getTitle() . ']]></name>';
        $row .= '<desc><![CDATA[' . $item->getContent() . ']]></desc>';
        $row .= '<metaDesc><![CDATA[' . $item->getMetaDescription() . ']]></metaDesc>';
        $row .= '<metaKeywords><![CDATA[' . $item->getMetaKeywords() . ']]></metaKeywords>';
        $row .= '<category>page</category>';
        $row .= '<url>' . htmlspecialchars($this->pageHelper->getPageUrl($item->getId())) . '</url>';

        return '<record>' . $row . '</record>';
    }
}